@@ -6,7 +6,7 @@ class DownloadInfo(Resource):
     """
     Download info resource contains download url for the file.
     """
-    url = HrefField()
+    url = HrefField(read_only=True)
 
     def __str__(self):
         return f'<DownloadInfo: url={self.url}>'
